@@ -115,8 +115,7 @@ class VagrantDriver(base.NodeDriver):
 
         try:
             with self._catalogue as c:
-                node_uuid = c.virtualbox_uuid(node)
-                virtualbox.attach_volume(node_uuid, volume.path, device)
+                virtualbox.attach_volume(node.id, volume.path, device)
                 volume.attached_to = node.name
                 c.update_volume(volume)
         except:
@@ -166,7 +165,8 @@ class VagrantDriver(base.NodeDriver):
             image = image.to_dict()
             for n in networks:
                 c.update_network(n)
-            node = VagrantNode(name=name,
+            node = VagrantNode(id=None,
+                               name=name,
                                public_ips=public_ips,
                                private_ips=private_ips,
                                driver=self,
@@ -177,6 +177,22 @@ class VagrantDriver(base.NodeDriver):
             c.save()  # Explicit save, so that the next command succeeds
             self.ex_start_node(node)
             self.log.info(".. Node '%s' created", name)
+
+            node.id = c.virtualbox_uuid(node)
+            c.add_node(node)
+            c.save()
+
+            public_networks = filter(lambda n: n.public, networks)
+            self.log.debug("create_node(%s): Public networks: %s",
+                           name, public_networks)
+            if public_networks:
+                ifaces = virtualbox.get_host_interfaces(node.id)
+                self.log.debug("create_node(%s): Ifaces: %s", name, ifaces)
+                for n, iface in zip(public_networks, ifaces):
+                    self.log.debug("create_node(%s): Iface for '%s': '%s'",
+                                   name, n.name, iface)
+                    n.host_interface = iface
+                    c.update_network(n)
             return node
 
     def create_volume(self, size, name, **kwargs):
@@ -218,12 +234,14 @@ class VagrantDriver(base.NodeDriver):
         :rtype: ``bool``
 
         """
-        try:
-            self._vagrant("box remove --force --provider virtualbox", image.id)
-            return True
-        except:
-            self.log.warn("Cannot remove image %s", image, exc_info=True)
-            return False
+        with self.catalogue:
+            try:
+                self._vagrant("box remove --force --provider virtualbox",
+                              image.id)
+                return True
+            except:
+                self.log.warn("Cannot remove image %s", image, exc_info=True)
+                return False
 
     def deploy_node(self, **kwargs):
         """Create a new node, and start deployment.
@@ -308,8 +326,13 @@ class VagrantDriver(base.NodeDriver):
             return True
         try:
             with self._catalogue as c:
-                node_uuid = c.virtualbox_uuid(node)
-                virtualbox.detach_volume(node_uuid, volume.path)
+                for n in c.get_nodes():
+                    if n.name == node:
+                        virtualbox.detach_volume(n.id, volume.path)
+                        break
+                else:
+                    self.log.warn("Volume '%s' attached to node '%s', "
+                                  "which does not exist", volume.name, node)
                 volume.attached_to = None
                 c.update_volume(volume)
                 return True
@@ -331,6 +354,7 @@ class VagrantDriver(base.NodeDriver):
         :rtype: ``bool``
 
         """
+        self.log.info("Destroying node '%s' ..", node.name)
         try:
             with self._catalogue as c:
                 self._vagrant("destroy --force", node.name)
@@ -345,6 +369,7 @@ class VagrantDriver(base.NodeDriver):
                         self.log.debug("destroy_node(): Detaching %s", v)
                         self.detach_volume(v)
                 c.remove_node(node)
+            self.log.info(".. Node '%s' destroyed", node.name)
             return True
         except:
             self.log.warn("Cannot destroy %s", node.name, exc_info=True)
@@ -477,12 +502,13 @@ class VagrantDriver(base.NodeDriver):
 
         """
         self.log.info("Rebooting node '%s' ..", node.name)
-        try:
-            self._vagrant("reload --no-provision", node.name)
-            self.log.info(".. Node '%s' rebooted", node.name)
-            return True
-        except:
-            self.log.debug("Cannot reload %s", node.name, exc_info=True)
+        with self._catalogue:
+            try:
+                self._vagrant("reload --no-provision", node.name)
+                self.log.info(".. Node '%s' rebooted", node.name)
+                return True
+            except:
+                self.log.debug("Cannot reload %s", node.name, exc_info=True)
 
     def wait_until_running(self, nodes, wait_period=3, timeout=600,
                            ssh_interface="public_ips", force_ipv4=True):
@@ -561,7 +587,8 @@ class VagrantDriver(base.NodeDriver):
         self.log.debug("ex_create_network(%s, %s, %s): Entering",
                        name, cidr, public)
         with self._catalogue as c:
-            network = VagrantNetwork(name, cidr, public, allocated=[])
+            network = VagrantNetwork(name, cidr, public,
+                                     allocated=[], host_interface=None)
             c.add_network(network)
             return network
 
@@ -579,10 +606,17 @@ class VagrantDriver(base.NodeDriver):
         :rtype:  ``Bool``
 
         """
+        self.log.info("Destroying network '%s' ..", network.name)
         try:
             with self._catalogue as c:
+                ifname = network.host_interface
+                self.log.debug("destoy_network(%s): Iface: %s",
+                               network.name, ifname)
+                if ifname is not None:
+                    virtualbox.destroy_host_interface(ifname)
                 c.remove_network(network)
                 return True
+            self.log.info(".. Network '%s' destroyed", network.name)
         except:
             self.log.warn("Cannot destroy network %s", network, exc_info=True)
             return False
@@ -600,7 +634,10 @@ class VagrantDriver(base.NodeDriver):
         """
         try:
             with self._catalogue as c:
-                node_uuid = c.virtualbox_uuid(node)
+                if node.id is None:
+                    node_uuid = c.virtualbox_uuid(node)
+                else:
+                    node_uuid = node.id
                 return virtualbox.get_node_state(node_uuid)
         except:
             self.log.warn("Cannot get node state for '%s'", node.name,
@@ -642,7 +679,10 @@ class VagrantDriver(base.NodeDriver):
         """
         self.log.info("Stopping node '%s' ..", node.name)
         with self._catalogue as c:
-            node_uuid = c.virtualbox_uuid(node)
+            if node.id is None:
+                node_uuid = c.virtualbox_uuid(node)
+            else:
+                node_uuid = node.id
             virtualbox.stop_node(node_uuid)
         self.log.info(".. Node '%s' stopped", node.name)
 
@@ -660,6 +700,8 @@ class VagrantDriver(base.NodeDriver):
         :rtype:  ``str``.
 
         """
+        env = dict(os.environ)
+        env["VAGRANT_LOG"] = "debug"
         cmdline = ["vagrant --machine-readable"]
         cmdline.extend(args)
         cmdline = " ".join(str(arg) for arg in cmdline)
@@ -667,12 +709,15 @@ class VagrantDriver(base.NodeDriver):
                        cmdline, self._dot_libcloudvagrant)
         p = subprocess.Popen(cmdline, shell=True,
                              stdout=subprocess.PIPE,
-                             stderr=subprocess.STDOUT,
+                             stderr=subprocess.PIPE,
+                             env=env,
                              cwd=self._dot_libcloudvagrant)
-        stdout, _ = p.communicate()
-        if p.returncode:
-            raise LibcloudError(stdout, driver=self)
+        stdout, stderr = p.communicate()
         self.log.debug(stdout)
+        if p.returncode:
+            self.log.warn("%s (cwd: %s) failed: %s",
+                          cmdline, self._dot_libcloudvagrant, stderr)
+            raise LibcloudError(stdout, driver=self)
         return stdout
 
     @property
