@@ -120,13 +120,14 @@ class VagrantNetwork(Serializable):
 
     log = logging.getLogger("libcloudvagrant")
 
-    def __init__(self, name, cidr, public, allocated):
+    def __init__(self, name, cidr, public, allocated, host_interface):
         self.name = name
         self.cidr = ipaddr.IPNetwork(cidr)
         self.public = public
         self._allocated = set()
         for ip in allocated:
             self._allocate(VagrantAddress(ip, name))
+        self.host_interface = host_interface
 
     @property
     def addresses(self):
@@ -212,6 +213,7 @@ class VagrantNetwork(Serializable):
             "cidr": str(self.cidr),
             "public": self.public,
             "allocated": sorted([str(ip.address) for ip in self._allocated]),
+            "host_interface": self.host_interface,
         }
 
     def __contains__(self, other):
@@ -220,12 +222,12 @@ class VagrantNetwork(Serializable):
 
 class VagrantNode(base.Node, Serializable):
 
-    def __init__(self, name, public_ips, private_ips, size, image, driver):
+    def __init__(self, id, name, public_ips, private_ips, size, image, driver):
         self._public_ips = [VagrantAddress(**p) for p in public_ips]
         self._private_ips = [VagrantAddress(**p) for p in private_ips]
         size = VagrantNodeSize.from_dict(driver=driver, **size)
         image = VagrantImage.from_dict(driver=driver, **image)
-        super(VagrantNode, self).__init__(id=name,
+        super(VagrantNode, self).__init__(id=id,
                                           name=name,
                                           state=NodeState.UNKNOWN,
                                           public_ips=self.public_ips,
@@ -272,6 +274,7 @@ class VagrantNode(base.Node, Serializable):
 
     def to_dict(self):
         return {
+            "id": self.id,
             "name": self.name,
             "public_ips": [
                 {"address": str(ip.address), "network_name": ip.network_name}
